==> guikachu-1.3.2.tar.gz: guikachu-1.3.2/src/form-editor/table.h <==
//$Id: table.h,v 1.15 2002/08/01 18:06:03 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_TABLE_H
#define GUIKACHU_FORM_EDITOR_TABLE_H

#include "widget.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Table;
    }
}

#include "resizeable.h"
#include "auto-resizeable.h"
#include <vector>

#include "table-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Table: public Widget,
		     public AutoWidth,
		     public AutoHeight
	{
	    GUI::FormEditor::TableProperties *editor;
	    VSignal columns_changed;
	    void update ();

	public:
	    Table (Resources::Form *owner, const std::string &id);
	    ~Table ();
	    
	    Type get_type () const { return WIDGET_TABLE; };
	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };

	    // Implementation of FormElement methods
	    Gtk::Widget                       *create_editor ();
	    GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);

	    Property<int>               num_rows;
	    Property<int>               num_columns;
	    Property<std::vector<int> > column_width;

	protected:
	    int get_auto_width  () const;
	    int get_auto_height () const;
	    
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_TABLE_H */

==> guikachu_1.4.0.orig.tar.gz: guikachu-1.4.0/src/form-editor/table.h <==
//$Id: table.h,v 1.18 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_TABLE_H
#define GUIKACHU_FORM_EDITOR_TABLE_H

#include "widget.h"

#include "resizeable.h"
#include "auto-resizeable.h"
#include <vector>

namespace Guikachu
{
    namespace Widgets
    {
	class Table: public Widget,
		     public AutoWidth,
		     public AutoHeight
	{
	    VSignal columns_changed;
	    void update ();

	public:
	    Table (Resources::Form *owner, const std::string &id, serial_t serial);
	    
	    Type get_type () const { return WIDGET_TABLE; };
	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };

	    Property<int>               num_rows;
	    Property<int>               num_columns;
	    Property<std::vector<int> > column_width;

	protected:
	    int get_auto_width  () const;
	    int get_auto_height () const;
	    
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_TABLE_H */
